<script setup>
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue';
import ProductFilter from '@/components/ProductFilter.vue'
import NavLink from '@/Components/NavLink.vue';
import { ref, onMounted, computed, reactive, watch } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';

const page = usePage();

const cart = computed(() => page.props.cart || []);
const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');
const quantities = reactive({});
const btnClass = "inline-flex items-center px-3 py-2 border border-transparent text-sm leading-4 font-medium rounded-md text-gray-500 bg-white hover:text-gray-700 focus:outline-none transition ease-in-out duration-150";

const form = useForm({});

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768; // Adjust the threshold as needed
}

onMounted(() => {
    window.addEventListener('resize', handleResize);
    handleResize();

    cart.value.forEach(product => {
        quantities[product.id] = product.cart_qty; // Default quantity
    });
});

const cartTotal = () => {
    let total = 0;
    cart.value.forEach(item => {
        total += item.price * quantities[item.id];
    });
    total = total.toFixed(2);
    return total;
};

const deleteCartItem = (cart) => {
    const cartID = cart.cart_id;

    form.post(route('cart.item.delete',{id: cartID}), {
        onSuccess: () => {
            flashMessage.value = "Cart item deleted";
            setTimeout(() => {
                window.location.reload();
            }, 1000); // Hide after 5 seconds
        },
        onError: (error) => {
            console.error(error);
        }
    });
};

const clearCart = async () => {
    console.log("Clear cart");
    try {
        await form.post(route('cart.clear'));
        flashMessage.value = "Cart cleared";
    } catch (error) {
        console.error(error);
    }
};

const updateCart = async () => {
    try {
        await form.post(route('cart.update',{quantities: quantities}));
        flashMessage.value = "Cart updated";
    } catch (error) {
        console.error(error);
    }
};

const gotoCheckout = () => {
    console.log("Go to checkout");
};

const singleProduct = (item_number) => {
    window.location.href = `/product/${item_number}`;
};
</script>

<template>
    <Head title="Cart" />

    <AuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Shopping Cart</h2>
        </template>

        <div class="py-12 container">
            <div class="row">
                <div v-if="flashMessage" class="col-12 max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                    <div class="form-row mb-6">
                        <div class="col-md-6">
                            <h4>{{ flashMessage }}</h4>
                        </div>
                    </div>
                </div>

                <div class="col-12 col-sm-3 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg">
                        <ProductFilter></ProductFilter>
                    </div>
                </div>
                <div class="col-12 col-sm-9 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div v-if="loading">Loading...</div>
                    <table v-else-if="cart && cart.length" class="table table-striped">
                        <thead>
                            <tr>
                                <th>Item Number</th>
                                <th v-if="!isMobile">Description</th>
                                <th>Price</th>
                                <th>Stock</th>
                                <th>Quantity</th>
                                <th></th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr v-for="product in cart" :key="product.id">
                                <td><a href="#" @click="singleProduct(product.item_number)">{{ product.item_number }}</a></td>
                                <td v-if="!isMobile" >{{ product.nags_description }}</td>
                                <td>{{ product.price }}</td>
                                <td :class="product.stock == 1 ? 'text-success' : 'text-danger'">{{ product.stock == 1 ? "In Stock" : "Please Call" }}</td>
                                <td class="cart_qty"><input v-if="product.stock == 1" v-model.number="quantities[product.id]" type="number" :name="`quantity_${product.id}`" id="cart_qty" min="1" /></td>
                                <td><button @click="deleteCartItem(product)">Delete</button></td>
                            </tr>
                        </tbody>
                    </table>
                    <p v-else>No Cart items found.</p>

                    <div v-if="cart && cart.length" class="col-12 col-sm-12 max-w-7xl mx-auto sm:px-6">
                        <hr />
                        <div class="row sm:py-3 lg:px-8">
                            <div class="col-12 text-right">Subtotal: ${{ cartTotal() }}</div>
                        </div>
                        <hr />
                        <div class="row">
                            <div class="col-7">
                                <NavLink :href="route('dashboard')" :active="route().current('dashboard')">
                                    <button :class="btnClass">Dashboard</button>
                                </NavLink>
                                <button :class="btnClass" @click="clearCart()">Clear All</button>
                            </div>
                            <div class="col-5 text-right">
                                <button :class="btnClass" @click="updateCart()">Update Cart</button>
                                <NavLink :href="route('checkout')" :active="route().current('checkout')">
                                    <button :class="btnClass">Checkout</button>
                                </NavLink>

                            </div>
                        </div>
                    </div>
                    <div v-else>
                        <NavLink :href="route('products.all')" :active="route().current('products.all')">
                            <button :class="btnClass">Go to shop</button>
                        </NavLink>
                    </div>
                </div>
            </div>
        </div>
    </AuthenticatedLayout>
</template>
<style scoped>
table tr td {
    max-width: 200px;
}
.cart_qty input {
    width: 70px;
    padding: 0 5px;
    height: 33px;
}
</style>
